@@ -1,8 +1,7 @@
+import json
 from json import JSONDecodeError
 from pathlib import Path
-from typing import Union, Dict, List
-
-import json
+from typing import Dict, List, Union
 
 from .api import get
 
@@ -32,6 +31,8 @@ async def load_json_from_url(
     if path and Path(path).exists() and not force:
         return load_json(path=path)
     resp = await get(url)
+    if resp.status_code != 200:
+        return []
     try:
         data: Union[Dict, List[Dict]] = resp.json()
     except JSONDecodeError:
